#
# spec file for package mpfc
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 2
Name:           mpfc
Version:        2.0
Release:        1699.2.pm.6
Summary:        Music Player for Linux Console
License:        GPL-2.0
Group:          Productivity/Multimedia/Sound/Players
Url:            https://code.google.com/p/mpfc/
Source:         http://sourceforge.net/projects/mpfc/files/mpfc/%{name}-%{version}.tar.bz2
Source1:        mpfc.desktop
Source99:       mpfc-rpmlintrc
#PATCH-FIX-UPSTREAM texinfo.patch avvissu@yandex.ru -- Fix no info dir entry in mpfc.info.gz
Patch0:         mpfc-2.0-texinfo.patch
#PATCH-FIX-UPSTREAM FSF.patch avvissu@yandex.ru -- Fix wrong fsf address
Patch1:         mpfc-2.0-FSF.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  gpm-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(vorbis)
%if 0%{?suse_version} >= 1320
BuildRequires:  pkgconfig(ncurses)
%else
BuildRequires:  ncurses-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

%package -n     libmpfc%{soname}
Summary:        Music Player for Linux Console Library
Group:          System/Libraries

%description -n libmpfc%{soname}
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

This package contains the libmpfc library, that is used by mpfc and its
plugins.

%package -n     libmpfc-devel
Summary:        Development environment for mpfc plugins
Group:          Development/Libraries/C and C++
Requires:       libmpfc%{soname} = %{version}

%description -n libmpfc-devel
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

This package contains the necessary environment to build mpfc plugins.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1

touch NEWS ChangeLog

%build
autoreconf -fiv
%if 0%{?suse_version} < 1320
export CURSES_CFLAGS="%{optflags} -Wall -Wno-unused -I%{_includedir}/ncursesw" \
export CURSES_LIBS="L%{libdir} -lncursesw -ltinfo"
%endif

%configure \
    --disable-rpath \
    --enable-gpm \
    --enable-cue \
    --enable-m3u \
    --enable-pls \
    --enable-audiocd \
	--enable-static=no

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

find %{buildroot} -type f -name "*.la" -delete -print

for p in general; do
    # using mkdir here on purpose, as mkdir_p and install -d fail silently if the
    # directory already exists, but we want the build to fail if mpfc suddenly has
    # plugins in there (to change the spec file accordingly)
    mkdir "%{buildroot}%{_libdir}/mpfc/$p"
done

install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"

%find_lang "%{name}"

%post   -n libmpfc%{soname} -p /sbin/ldconfig

%postun -n libmpfc%{soname} -p /sbin/ldconfig

%post
%if 0%{?suse_version} >= 1140
%desktop_database_post
%endif
%install_info --info-dir="%{_infodir}" "%{_infodir}/mpfc.info%{ext_info}"

%postun
%if 0%{?suse_version} >= 1140
%desktop_database_postun
%endif
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/mpfc.info%{ext_info}"

%files -f "%{name}.lang"
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_infodir}/mpfc.info%{ext_info}
%{_mandir}/man1/mpfc.1%{ext_man}
%{_datadir}/applications/%{name}.desktop
#%config(noreplace) %{_sysconfdir}/mpfcrc

%files -n libmpfc%{soname}
%defattr(-,root,root)
%{_libdir}/libmpfc.so.%{soname}
%{_libdir}/libmpfc.so.%{soname}.*
%{_libdir}/libmpfcwnd.so.%{soname}
%{_libdir}/libmpfcwnd.so.%{soname}.*

%files -n libmpfc-devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libmpfc.so
%{_libdir}/libmpfcwnd.so
%{_libdir}/pkgconfig/mpfc.pc

%changelog
* Wed Feb 25 2015 avvissu@yandex.ru
- Update to 2.0:
  * Completely new audio backend using GStreamer. The old plugins
  model is no longer used
  * Remote control interface (plus an Android remote)
  * Cesheet improvements
  * Unicode improvements. UTF-8 locale is now explicitly required
  * Minor UI improvements.
- Project moved to Google Code: change url
- Remove all patch (fixed in upstream):
  * mpfc-fix_missing_includes.patch
  * mpfc-fix_missing_std_headers.patch
  * mpfc-getaddrinfo.patch
- Fix no info dir entry in mpfc.info.gz (mpfc-2.0-texinfo.patch)
- Fix wrong fsf address (mpfc-2.0-FSF.patch)
- Change mpfc.desktop and add %%desktop_database_post
- Spec file cleanup
* Tue Feb 24 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2:
  * change path to mpfc.info in %%post macro
* Sat Mar 12 2011 pascal.bleser@opensuse.org
- initial version (1.3.8)
